Package: mergeHMM
Type: Package
Title: Merging states of hidden Markov models.
Version: 1.0
Date: 2013-05-06
Author: Florian Schwaiger
Maintainer: Florian Schwaiger <schwaige@mathematik.uni-marburg.de>
Description: In Holzmann and Schwaiger (2013) hidden Markov models with state-dependent finite mixtures are analyzed. The two proposed algorithms to find an appropriate model and to find density based clusters are here implemented for the uni- and multivariate normal distribution.
License: GPL-2
Depends: methods,sn, mvtnorm, RHmm, parallel, CombMSC
Packaged: 2013-06-13 11:43:35 UTC; schwaige
