extern2intern <-
function(parameter,distribution,m){
  
  if(distribution=="poisson"){
    return(as.list(parameter))  
  }
  
  if(distribution=="normal"){
    startP = list()
    for(i in 1:m) startP[[i]]=c((parameter$mu)[i],(parameter$sigma)[i])
    return(startP)
  }
  
  if(distribution=="mv_normal"){
    startP = list()
    for(i in 1:m)
      startP[[i]]=list(mu = (parameter$mu)[,i], sigma=(parameter$sigma)[,,i])  
    return(startP)
    }

}
