stat_distr <-
function(mat){
  m0=dim(mat)[1]
  I_m = diag(rep(1,m0))
  U = matrix(rep(1,m0*m0),nrow=m0)
  M = I_m - mat + U
  One = matrix(rep(1,m0),nrow=1)
  erg = One %*% solve(M)
  return(as.vector(erg))
}
