\name{show-methods}
\docType{methods}
\alias{show-methods}
\alias{show}
\alias{show,ANY-method}
\alias{show,hmmClass-method}
\alias{show,hmmClassNormal-method}
\alias{show,hmmClassMvNormal-method}
\title{ Output of HMMs on console.}
\description{
Provides for each HMM an output on the console.
}
