\name{stat_distr}
\alias{stat_distr}
\title{
Calculating the stationary distribution of a MC}
\description{
This function can be used to calculate the stationary distribution of a given Markov chain (parameterized by a transition probability matrix \code{mat}). 
This function is not written by us (see reference), but very useful when working with the present type of models, and therefore added to the package.
}
\usage{
stat_distr(mat)
}
\arguments{
  \item{mat}{
The tpm of a Markov chain.}
}
\value{
A vector of probabilities, which is the stationary distribution of the Markov chain.}
\references{
Zucchini and MacDonald (2009). Hidden Markov Models for Time Series: An Introduction Using R.}
\author{
Zucchini and MacDonald (2009)
}

